##  Use the UI
While we also have our [REST API](https://help.sap.com/docs/leanix/ea/integration-rest-api?locale=en-US&state=PRODUCTION&version=CLOUD "How to connect to the Integration API from an external system.") available, it is highly recommended to setup your processors in the UI before addressing the API.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757e2ee7a441014b3cdc221d87a1a3f_LowRes.png)
Utilizing the UI allows for quick testing and debugging of processors.
